NeumorphicIcon class

An icon widget with Neumorphic styling.

Inheritance

Constructors

NeumorphicIcon({Key? key, required IconData icon, double size = 24.0, Color? color, NeumorphicProperties? style, VoidCallback? onPressed, bool enabled = true, Duration pressDuration = const Duration(milliseconds: 100)})
Creates a Neumorphic icon.
const

Properties

color Color?
The color of the icon.
final
enabled bool
Whether the icon is enabled.
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
The icon to display.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed VoidCallback?
Called when the icon is tapped.
final
pressDuration Duration
The duration of the press animation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
The size of the icon.
final
style NeumorphicProperties?
The style properties for this icon.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NeumorphicIcon>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited